@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -480,15 +480,24 @@ function item_edit() {
 	});
 
 	function get_size() {
-		$.get('data_source_profiles.php?action=ajax_size&type=rra&id='+profile_id+'&rows='+$('#rows').val(), function(data) {
-			$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_size&type=rra&id='+profile_id+'&rows='+$('#rows').val())
+			.done(function(data) {
+				$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
 	}
 
 	function get_span() {
-		$.get('data_source_profiles.php?action=ajax_span&profile_id='+profile_id+'&span='+$('#steps').val()+'&rows='+$('#rows').val(), function(data) {
-			$('#row_retention').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_span&profile_id='+profile_id+'&span='+$('#steps').val()+'&rows='+$('#rows').val())
+			.done(function(data) {
+				$('#row_retention').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
+
 	}
 	</script>
 	<?php
@@ -622,15 +631,19 @@ function profile_edit() {
 
 			id = $(this).attr('id').split('_');
 			request = 'data_source_profiles.php?action=item_remove_confirm&id='+id[1]+'&profle_id='+id[0];
-			$.get(request, function(data) {
-				$('#cdialog').html(data);
-				applySkin();
-				$('#cdialog').dialog({
-					title: '<?php print __('Delete Data Source Profile Item');?>',
-					close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
-					minHeight: 80,
-					minWidth: 500
-				});
+			$.get(request)
+				.done(function(data) {
+					$('#cdialog').html(data);
+					applySkin();
+					$('#cdialog').dialog({
+						title: '<?php print __('Delete Data Source Profile Item');?>',
+						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
+						minHeight: 80,
+						minWidth: 500
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
+					});
 			});
 		}).css('cursor', 'pointer');
 		<?php } else { ?>
@@ -644,9 +657,13 @@ function profile_edit() {
 
 	function get_size() {
 		checked = $('#consolidation_function_id').multiselect('getChecked').length;
-		$.get('data_source_profiles.php?action=ajax_size&type=profile&id='+profile_id+'&cfs='+checked, function(data) {
-			$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_size&type=profile&id='+profile_id+'&cfs='+checked)
+			.done(function(data) {
+				$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
 	}
 
 	</script>
@@ -950,6 +967,18 @@ function profile() {
 				$readonly = false;
 			}
 
+			if ($profile['data_sources'] > 0) {
+				$ds = '<a class="linkEditMain" href="' . $config['url_path'] . 'data_sources.php?reset=true&profile=' . $profile['id'] . '">' . number_format_i18n($profile['data_sources'], '-1') . '</a>';
+			} else {
+				$ds = number_format_i18n($profile['data_sources'], '-1');
+			}
+
+			if ($profile['templates'] > 0) {
+				$dt = '<a class="linkEditMain" href="' . $config['url_path'] . 'data_templates.php?reset=true&profile=' . $profile['id'] . '">' . number_format_i18n($profile['templates'], '-1') . '</a>';
+			} else {
+				$dt = number_format_i18n($profile['templates'], '-1');
+			}
+
 			form_alternate_row('line' . $profile['id'], false, $disabled);
 			form_selectable_cell(filter_value($profile['name'], get_request_var('filter'), 'data_source_profiles.php?action=edit&id=' . $profile['id']), $profile['id']);
 			form_selectable_cell($profile['default'] == 'on' ? __('Yes'):'', $profile['id'], '', 'text-align:right');
@@ -957,8 +986,8 @@ function profile() {
 			form_selectable_cell($readonly ? __('Yes') : __('No'), $profile['id'], '', 'text-align:right');
 			form_selectable_cell($sampling_intervals[$profile['step']], $profile['id'], '', 'text-align:right');
 			form_selectable_cell($heartbeats[$profile['heartbeat']], $profile['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($profile['data_sources'], '-1'), $profile['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($profile['templates'], '-1'), $profile['id'], '', 'text-align:right');
+			form_selectable_cell($ds, $profile['id'], '', 'text-align:right');
+			form_selectable_cell($dt, $profile['id'], '', 'text-align:right');
 			form_checkbox_cell($profile['name'], $profile['id'], $disabled);
 			form_end_row();
 		}
