@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -117,7 +117,7 @@ case 'countdown':
 		$graph_data_array['graph_end'] = time();
 	}
 
-	/* print RRDTool graph source? */
+	/* print RRDtool graph source? */
 	if (!isempty_request_var('show_source')) {
 		$graph_data_array['print_source'] = get_request_var('show_source');
 	}
@@ -216,32 +216,8 @@ $selectedTheme = get_selected_theme();
 ?>
 <html>
 <head>
-    <meta http-equiv='X-UA-Compatible' content='edge'>
-	<meta content='width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0' name='viewport'>
-	<meta name='apple-mobile-web-app-capable' content='yes'>
-	<meta name='mobile-web-app-capable' content='yes'>
-	<title><?php print __('Cacti Real-time Graphing');?></title>
-    <meta http-equiv='Content-Type' content='text/html;charset=utf-8'>
-    <link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/main.css' type='text/css' rel='stylesheet'>
-    <link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/jquery.zoom.css' type='text/css' rel='stylesheet'>
-    <link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/jquery-ui.css' type='text/css' rel='stylesheet'>
-    <link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/default/style.css' type='text/css' rel='stylesheet'>
-    <link href='<?php echo $config['url_path']; ?>include/fa/css/font-awesome.css' type='text/css' rel='stylesheet'>
-    <link href='<?php echo $config['url_path']; ?>images/favicon.ico' rel='shortcut icon'>
-    <?php api_plugin_hook('page_head'); ?>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.js' language='javascript'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery-migrate.js' language='javascript'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery-ui.js' language='javascript'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.cookie.js' language='javascript'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jstree.js'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.hotkeys.js'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.zoom.js' language='javascript'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.tablesorter.js' language='javascript'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/layout.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/realtime.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/pace.js'></script>
-    <script type='text/javascript' src='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/main.js'></script>
-    <?php include($config['base_path'] . '/include/global_session.php'); api_plugin_hook('page_head'); ?>
+	<?php html_common_header(__('Cacti Real-time Graphing'));?>
+    <?php include($config['base_path'] . '/include/global_session.php'); ?>
 </head>
 <body style='text-align: center; padding: 5px 0px 5px 0px; margin: 5px 0px 5px 0px;'>
 <form method='post' action='graph_popup_rt.php' id='gform'>
@@ -252,7 +228,7 @@ $selectedTheme = get_selected_theme();
 					<?php print __('Window');?>
 				</td>
 				<td>
-					<select name='graph_start' id='graph_start' onChange='imageOptionsChanged("timespan")'>
+					<select id='graph_start' onChange='imageOptionsChanged("timespan")'>
 					<?php
 					foreach ($realtime_window as $interval => $text) {
 						printf('<option value="%d"%s>%s</option>',
@@ -266,7 +242,7 @@ $selectedTheme = get_selected_theme();
 					<?php print __('Refresh');?>
 				</td>
 				<td>
-					<select name='ds_step' id='ds_step' onChange="imageOptionsChanged('interval')">
+					<select id='ds_step' onChange="imageOptionsChanged('interval')">
 					<?php
 					foreach ($realtime_refresh as $interval => $text) {
 						printf('<option value="%d"%s>%s</option>',
