@@ -416,7 +416,11 @@ function form_actions() {
 					$form_array += array($field_name => $fields_host_edit[$field_name]);
 
 					$form_array[$field_name]['value'] = '';
-					$form_array[$field_name]['description'] = '';
+
+					if (read_config_option('hide_form_description') == 'on') {
+						$form_array[$field_name]['description'] = '';
+					}
+
 					$form_array[$field_name]['form_id'] = 0;
 					$form_array[$field_name]['sub_checkbox'] = array(
 						'name' => 't_' . $field_name,
@@ -435,6 +439,8 @@ function form_actions() {
 
 			device_javascript();
 
+			device_change_javascript();
+
 			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Change Device(s) SNMP Options') . "'>";
 		} elseif (get_request_var('drp_action') == '5') { // Clear Statisitics for Selected Devices
 			print "<tr>
@@ -963,6 +969,52 @@ function device_reindex_methods($item, $host) {
 	}
 }
 
+function device_change_javascript() {
+	?>
+	<script type="text/javascript">
+	function disableField(id) {
+		$('#'+id).prop('disabled', true);
+
+		if ($('#'+id).button('instance')) {
+			console.log('button');
+			$('#'+id).button('disable');
+		} else if ($('#'+id).selectmenu('instance')) {
+			console.log('selectmenu');
+			$('#'+id).selectmenu('disable');
+		}
+	}
+
+	function enableField(id) {
+		$('#'+id).prop('disabled', false);
+
+		if ($('#'+id).button('instance')) {
+			console.log('button');
+			$('#'+id).button('enable');
+		} else if ($('#'+id).selectmenu('instance')) {
+			console.log('selectmenu');
+			$('#'+id).selectmenu('enable');
+		}
+	}
+
+	$(function() {
+		$('input[id^="t_"]').click(function() {
+			id = $(this).attr('id').substring(2);
+			if ($(this).is(':checked')) {
+				enableField(id);
+			} else {
+				disableField(id);
+			}
+		});
+
+		$('input[id^="t_"]').each(function() {
+			id = $(this).attr('id').substring(2);
+			disableField(id);
+		});
+	});
+	</script>
+	<?php
+}
+
 function device_javascript() {
 	?>
 	<script type="text/javascript">
@@ -1173,10 +1225,14 @@ function device_javascript() {
 			changeHostForm();
 		});
 
-		$.get(urlPath+'host.php?action=ping_host&id='+$('#id').val(), function(data) {
-			$('#ping_results').html(data);
-			hostInfoHeight = $('.hostInfoHeader').height();
-		});
+		$.get(urlPath+'host.php?action=ping_host&id='+$('#id').val())
+			.done(function(data) {
+				$('#ping_results').html(data);
+				hostInfoHeight = $('.hostInfoHeader').height();
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
 
 		$('input[id^="reindex_"]').change(function() {
 			strURL  = urlPath+'host.php?action=query_change&header=false';
