@@ -30,7 +30,12 @@ function imageOptionsChanged(action) {
 	graph_start    = $("#graph_start").val();
 	graph_end      = 0;
 	ds_step        = $("#ds_step").val();
-	local_graph_id = $('#local_graph_id').val();
+
+	if ($('#local_graph_id').length) {
+		local_graph_id = $('#local_graph_id').val();
+	} else {
+		local_graph_id = 0;
+	}
 
 	if (rtWidth == 0) {
 		rtWidth = $(window).width();
@@ -40,13 +45,17 @@ function imageOptionsChanged(action) {
 		rtHeight = $(window).height()+50;
 	}
 
-	url="?top=0&left=0&action="+action+"&local_graph_id="+local_graph_id+"&graph_start=-"+graph_start+"&ds_step="+ds_step+"&count="+count;
+	url="graph_realtime.php?top=0&left=0&action="+action+"&local_graph_id="+local_graph_id+"&graph_start=-"+graph_start+"&ds_step="+ds_step+"&count="+count;
 
 	Pace.stop;
 
-	$.getJSON(url, function(data) {
-		$('#image').empty().append('<img class="graphimage" src="data:image/png;base64,'+data.data+'"/>');
-	});
+	$.getJSON(url)
+		.done(function(data) {
+			$('#image').empty().append('<img class="graphimage" src="data:image/png;base64,'+data.data+'"/>');
+		})
+		.fail(function(data) {
+			getPresentHTTPError(data);
+		});
 }
 
 function stopRealtime() {
@@ -126,17 +135,22 @@ function realtimeGrapher() {
 			Pace.ignore(function() {
 				position = $('#wrapper_'+local_graph_id).find('img').position();
 
-				$.get(urlPath+'graph_realtime.php?action=countdown&top='+parseInt(position.top)+'&left='+parseInt(position.left)+(isThumb ? '&graph_nolegend=true':'')+'&graph_end=0&graph_start=-'+graph_start+'&local_graph_id='+local_graph_id+'&ds_step='+ds_step+'&count='+count, function(data) {
-					results = $.parseJSON(data);
+				$.get(urlPath+'graph_realtime.php?action=countdown&top='+parseInt(position.top)+'&left='+parseInt(position.left)+(isThumb ? '&graph_nolegend=true':'')+'&graph_end=0&graph_start=-'+graph_start+'&local_graph_id='+local_graph_id+'&ds_step='+ds_step+'&count='+count)
+					.done(function(data) {
+						results = $.parseJSON(data);
 
-					$('#graph_'+results.local_graph_id).prop('src', 'data:image/png;base64,'+results.data).change();
+						$('#graph_'+results.local_graph_id).prop('src', 'data:image/png;base64,'+results.data).change();
+
+						if (isThumb) {
+							$('#graph_'+results.local_graph_id).width(rtWidth).height(rtHeight);
+						}else{
+							$('#graph_'+results.local_graph_id);
+						}
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
+					});
 
-					if (isThumb) {
-						$('#graph_'+results.local_graph_id).width(rtWidth).height(rtHeight);
-					}else{
-						$('#graph_'+results.local_graph_id);
-					}
-				});
 			});
 		}
 	}
@@ -148,3 +162,4 @@ function realtimeGrapher() {
 		realtimeTimer = setTimeout('realtimeGrapher()', $('#ds_step').val()*1000);
 	}
 }
+
